.. testsetup:: *

   from pwnlib.tubes.buffer import *

:mod:`pwnlib.tubes.buffer` --- buffer implementation for tubes
==============================================================

.. automodule:: pwnlib.tubes.buffer
   :members:
